Class: Skykick::Client
- Defined in:
- lib/skykick/client.rb,
lib/skykick/client/alerts.rb,
lib/skykick/client/backup.rb
Overview
Note:
All methods are grouped in separate modules for better organization and follow the structure provided in the official API documentation.
The Skykick::Client class acts as a wrapper for the Skykick REST API.
This class inherits from the Skykick::API class and includes modules that group
the API methods according to the structure in the Skykick API documentation.
Defined Under Namespace
Method Summary
Methods included from Alerts
Methods included from Backup
#autodiscover, #datacenters, #exchange_mailbox, #exchange_mailboxes, #lastsnapshotstats, #partner_subscriptions, #retentionperiod, #sharepoint_sites, #sku, #storage_settings, #subscription_settings, #subscriptions
Methods inherited from API
Methods included from Authentication
Methods included from Connection
#setup_headers, #setup_logger_filtering
Constructor Details
This class inherits a constructor from Skykick::API